# R script prepared to analyse the outcome of the perception test presented in
# the paper "Visual channel facilitates the comprehension of 
# the intonation of Brazilian Portuguese wh-questions and wh-exclamations: evidence 
# from congruent and incongruent stimuli", submitted to LAC 2023
# 
# 


stop("do not run")

# clean
rm(list = ls())

# you need to set the default folder to the place were the dataset is
setwd("~")

# load the dataset
M <- read.csv("data_miranda_moraes_rilliard_LAC23.csv", stringsAsFactors = TRUE)

# let the speakers be factor
M$Spk <- as.factor(M$Spk)

# add the age of the speakers
age <- list("1"= 24, "2"= 26, "3"= 64, "4"= 27, "5"= 28, "6"= 27, "7"= 22, "8"= 25, "9"= 23, "10"= 19)
M$Age <- unlist(age[as.character(M$Spk)])
rm(age)

# create a variable with hit and miss answers
M$Y <- cbind(M$Hit, M$Miss)


## Short descriptive quantitative analysis 
head(M)
summary(M)


## Number of answers in each category + proportion
# For ASP
xtabs(Hit ~ ASP, data = M)
xtabs(Total ~ ASP, data = M)
xtabs(Hit ~ ASP, data = M) / xtabs(Total ~ ASP, data = M)

# For Congruence
xtabs(Hit ~ Cgr, data = M)
xtabs(Total ~ Cgr, data = M)
xtabs(Hit ~ Cgr, data = M) / xtabs(Total ~ Cgr, data = M)

# For both factors
xtabs(Hit ~ ASP + Cgr, data = M)
xtabs(Total ~ ASP + Cgr, data = M)
round(xtabs(Hit ~ ASP + Cgr, data = M) / xtabs(Total ~ ASP + Cgr, data = M), 2)

# We have a potential effect of both factors
# Let's do a plot of the mean proportions
tab <- round(xtabs(Hit ~ ASP + Cgr, data = M) / xtabs(Total ~ ASP + Cgr, data = M), 2)

pdf("Figure_1.pdf", width = 7, height = 5)
barplot(tab, 
        beside = TRUE, 
        ylim = c(0, 1), 
        col = c("lightgrey", "grey4"), # B&W
        # col = c("red4", "green4"), 
        xlab = "Congruence", ylab = "Proportion of Hit")
box()
abline(h=seq(.2,.8,.2), lty = 3, col ="grey")
legend("topright", legend = levels(M$ASP), 
       fill = c("lightgrey", "grey4"), # B&W
       # fill = c("red4", "green4"), 
       title = "ASP", ncol = 2)
barplot(tab, beside = TRUE, ylim = c(0, 1), 
        col = c("lightgrey", "grey4"), # B&W
        # col = c("red4", "green4"),
        add = TRUE)
dev.off()

rm(tab)



## Modelling process

## test a potential confounding factor of speaker's AGE
## To that effect, needs to remove the "spk" factor to avoid multicolinearity

options(contrasts=c("contr.treatment","contr.poly"))


m1 <- glm(Y ~ ASP * Cgr * Age, data = M, family = binomial)
summary(m1)


# Simplification process
# remove the triple interaction
m2 <- update(m1, ~ . - ASP:Cgr:Age)
anova(m1, m2, test="Chisq")
# non significant triple interaction: continue simplification

# test the two-ways interactions
m3a <- update(m2, ~ . - ASP:Age)
anova(m2, m3a, test="Chisq")
m3b <- update(m2, ~ . - Cgr:Age)
anova(m2, m3b, test="Chisq")
m3c <- update(m2, ~ . - ASP:Cgr)
anova(m2, m3c, test="Chisq")
#  none of the two ways interactions are usefull : simplified model
m3 <- glm(Y ~ ASP + Cgr + Age, data = M, family = binomial)
anova(m2, m3, test="Chisq")

# test the main factors
m4a <- update(m3, ~ . - Age)
anova(m3, m4a, test="Chisq")
m4b <- update(m3, ~ . - Cgr)
anova(m3, m4b, test="Chisq")
m4c <- update(m3, ~ . - ASP)
anova(m3, m4c, test="Chisq")

## Age does not explain a significant part of the variance: we shall not use it 
## and use the SPEAKER factor instead: it seems individual speakers have different 
## behaviour, independently of their AGE
rm(list = ls(pattern = "m+"))


##
# Let's fit a binomial model with three factors : ASP, Cgr and Spk

options(contrasts=c("contr.treatment","contr.poly"))

m1 <- glm(Y ~ ASP * Cgr * Spk, data = M, family = binomial)
summary(m1)

m2 <- update(m1, ~ . - ASP:Cgr:Spk)
anova(m1, m2, test="Chisq")

# the three way interaction was not significant: let's test the 2-way
m3a <- update(m2, ~ . - ASP:Cgr)
anova(m2, m3a, test="Chisq")
m3b <- update(m2, ~ . - ASP:Spk)
anova(m2, m3b, test="Chisq")
m3c <- update(m2, ~ . - Cgr:Spk)
anova(m2, m3c, test="Chisq")

# the two interactions with SPEAKER are significant =>
m3 <- glm(Y ~ ASP + Cgr + Spk + ASP:Spk + Cgr:Spk, data = M, family = binomial)
anova(m2, m3, test="Chisq")
summary(m3)


# It seems some speakers have similar behaviour. Let's try to regroup them
# a rapid plot
plot(effects::effect("ASP:Cgr:Spk", m3),
     lines=list(multiline=FALSE, lty=0, col = c("black")), 
     confint=list(style="bars"), 
     rescale.axis=FALSE, ylim=c(0, 1), 
     axes=list(grid=TRUE),
     main = NULL, xlab = "Audio speech act", ylab = "Proportion correct")


##  Let's regroup the speakers in five groups 
##  2&4  1&7 -  10&3&5&8 -- plus individual speakers 6 and 9
M$Spk5 <- M$Spk
levels(M$Spk5) <- c("1/7", "2/4", "3/5/8/10", "2/4", "3/5/8/10", "6", "1/7", "3/5/8/10", "9", "3/5/8/10")
levels(M$Spk5)

# refit the model with groups of speakers
m4 <- glm(Y ~ ASP + Cgr + Spk5 + ASP:Spk5 + Cgr:Spk5, data = M, family = binomial)
anova(m3, m4, test="Chisq")
summary(m4)



### Summaries of the model
summary(m4)

### Anova TABLE : type II or Type III ss  (cf. Gries 2013)
options(contrasts=c("contr.sum", "contr.poly"))       # set sum contrasts
Anova(m4, type="III", test.statistic="LR")            # compute anova of model with type III sums of squares
options(contrasts=c("contr.treatment", "contr.poly")) # reset to treatment contrasts

# Parameters of the model with CI etc. (table 1)
parameters::model_parameters(m4)
# exponenciated
parameters::model_parameters(m4, exponentiate = TRUE)



# Tests post hoc
library(phia)

# Comparison of speaker groups across each levels of congruence
testInteractions(m4, pairwise = c("Spk5"), fixed = c("Cgr"), adjustment = "bonferroni")
# Comparison of congruence levels across each speaker group
testInteractions(m4, pairwise = c("Cgr"), fixed = c("Spk5"), adjustment = "bonferroni")

# Comparison of speaker groups across each levels of ASP
testInteractions(m4, pairwise = c("Spk5"), fixed = c("ASP"), adjustment = "bonferroni")
# Comparison of ASP levels across each speaker group
testInteractions(m4, pairwise = c("ASP"), fixed = c("Spk5"), adjustment = "bonferroni")




## Plots
summary(m4)

# pdf("NONAME.pdf", width = 3.5, height = 4.5)
plot(Effect("ASP", m4),
     lines=list(multiline=FALSE, lty=0, col = c("black")), 
     confint=list(style="bars"), 
     rescale.axis=FALSE, ylim=c(0, 1), 
     axes=list(grid=TRUE),
     main = NULL, xlab = "Audio speech act", ylab = "Proportion correct")
# dev.off()

# pdf("NONAME.pdf", width = 5.5, height = 4.5)
plot(Effect("Cgr", m4),
     lines=list(multiline=FALSE, lty=0, col = c("black")), 
     confint=list(style="bars"), 
     rescale.axis=FALSE, ylim=c(0, 1), 
     axes=list(grid=TRUE),
     main = NULL, xlab = "Audio-Visual congruence", ylab = "Proportion correct")
# dev.off()

# pdf("NONAME.pdf", width = 6.5, height = 4.5)
plot(Effect("Spk5", m4),
     lines=list(multiline=FALSE, lty=0, col = c("black")), 
     confint=list(style="bars"), 
     rescale.axis=FALSE, ylim=c(0, 1), 
     axes=list(grid=TRUE),
     main = NULL, xlab = "Speaker groups", ylab = "Proportion correct")
# dev.off()

pdf("Figure_4.pdf", width = 6.5, height = 4.5)
plot(Effect(c("Cgr","Spk5"), m4), 
     lines=list(multiline = TRUE , lty=c(1,2), col = c("red4", "green4")),
     rescale.axis=FALSE, ylim=c(0, 1), axes=list(grid=TRUE), confint=list(style="bars"),
     lattice=list(key.args = list(title = "Congruence", columns = 2)),
     main = NULL, xlab = "Speaker groups", ylab = "Proportion correct")#,
dev.off()

pdf("Figure_5.pdf", width = 6.5, height = 4.5)
plot(Effect(c("ASP","Spk5"), m4), 
     lines=list(multiline = TRUE , lty=c(1,2), col = c("red4", "green4")),
     rescale.axis=FALSE, ylim=c(0, 1), axes=list(grid=TRUE), confint=list(style="bars"),
     lattice=list(key.args = list(title = "Speech act", columns = 2)),
     main = NULL, xlab = "Speaker groups", ylab = "Proportion correct")#,
dev.off()




